==> jaxrs-ri-2.3.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/routing/MatchResultInitializerRouter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.routing;

import javax.inject.Inject;
import javax.inject.Provider;

import org.glassfish.jersey.server.ContainerRequest;

/**
 * Request matching bootstrapping stage that pushes the whole request path to the routing
 * context as a right-hand path to be matched.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
final class MatchResultInitializerRouter implements Router {

    /**
     * "Assisted injection" factory interface for {@link MatchResultInitializerRouter}.
     *
     * See also <a href="http://code.google.com/p/google-guice/wiki/AssistedInject">
     * assisted injection in Guice</a>.
     */
    public static class Builder {

        @Inject
        private Provider<RoutingContext> contextProvider;

        /**
         * Build a match result initializer.
         *
         * @param rootRoute matching root.
         * @return a match result initializer.
         */
        public MatchResultInitializerRouter build(Router rootRoute) {
            return new MatchResultInitializerRouter(contextProvider, rootRoute);
        }
    }

    private final Provider<RoutingContext> contextProvider;
    private final Router rootRouter;

    private MatchResultInitializerRouter(Provider<RoutingContext> contextProvider, Router rootRouter) {
        this.contextProvider = contextProvider;
        this.rootRouter = rootRouter;
    }

    @Override
    public Continuation apply(final ContainerRequest requestContext) {
        final RoutingContext rc = contextProvider.get();
        rc.pushMatchResult(new SingleMatchResult(requestContext.getPath(false)));

        return Continuation.of(requestContext, rootRouter);
    }
}

==> jaxrs-ri-2.10.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/routing/MatchResultInitializerRouter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.routing;

import org.glassfish.jersey.server.internal.process.RequestProcessingContext;

/**
 * Request matching bootstrapping stage that pushes the whole request path to the routing
 * context as a right-hand path to be matched.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
final class MatchResultInitializerRouter implements Router {

    private final Router rootRouter;

    /**
     * Create a new match result initializer.
     *
     * @param rootRouter root router.
     */
    MatchResultInitializerRouter(Router rootRouter) {
        this.rootRouter = rootRouter;
    }

    @Override
    public Continuation apply(final RequestProcessingContext processingContext) {
        final RoutingContext rc = processingContext.routingContext();
        rc.pushMatchResult(new SingleMatchResult("/" + processingContext.request().getPath(false)));

        return Continuation.of(processingContext, rootRouter);
    }
}
